// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// -*-C++-*-
//
// File:      OmSourceParameters.h
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Fri Aug  9 16:49:17 MEST 2002

#ifndef OmSourceParameters_h
#define OmSourceParameters_h

#include "DopeVector.h"
#include "Dal.h"

// equivalent of f90::type(OmSourceParameter)
struct OmSourceParameter {
    OmSourceParameter() :
    rightascension(0), 
    declination(0),  
    xcoord(0), 
    ycoord(0),
    positionerror(0),
    exposure(0), 
    significance(0),
    rawcountrate(0), 
    rawcountrateerror(0),
    corrcountrate(0),
    corrcountrateerror(0),  //
    magnitude(0),
    magnitudeerror(0),  
    rawbackgroundcountrate(0),
    rawbackgroundcountrateerror(0),
    corrbackgroundcountrate(0),
    corrbackgroundcountrateerror(0),
    psf1correction(0),
    psf2correction(0),
    coincidencecorrection(0), 
    tdscorrection(0), 
    semia(0),
    semiaerr(0),
    semib(0),
    semiberr(0),
    theta(0),  
    thetaerr(0), 
    photometryradius(0),   // was 0
    axialRatio(1.0),
    alpha(0.0), 
    innerbackgroundradius(0),
    outerbackgroundradius(0),
    number(0), 
    nosourcepixels(0),
    qualityflag(0),
    iMin(0), iMax(0), jMin(0), jMax(0),
    extensionflag(0),
    confusionflag(0)

  {}   

    double rightascension; 
    double declination;  
    float xcoord; 
    float ycoord;
    float positionerror;
    float exposure; 
    float significance;
    float rawcountrate; 
    float rawcountrateerror;
    float corrcountrate;
    float corrcountrateerror;  //
    float magnitude;
    float magnitudeerror;  
    float rawbackgroundcountrate;
    float rawbackgroundcountrateerror;
    float corrbackgroundcountrate;
    float corrbackgroundcountrateerror;
    float psf1correction;
    float psf2correction;
    float coincidencecorrection;
    float tdscorrection;
    float semia;
    float semiaerr;
    float semib;
    float semiberr;
    float theta;  
    float thetaerr;
    float photometryradius;
    float axialRatio;
    float alpha;   
    float innerbackgroundradius;
    float outerbackgroundradius;
    int number; 
    int nosourcepixels;
    int16 qualityflag;
    int16 iMin; 
    int16 iMax; 
    int16 jMin; 
    int16 jMax; 
    int8 extensionflag;  // was Integer2
    int8 confusionflag; 

   };



/*****************************************************
 The observation details
*****************************************************/
struct PhotometryParameters {

  PhotometryParameters() : 
    apertureRadius(0),  
    calApertureRadius(0),
    binX(1) 
          
  {
  }
    float apertureRadius;
    float calApertureRadius;
    int binX;    
};


/*****************************************************
*  
*****************************************************/
struct FittedParameters {

    FittedParameters()
          
    {
    }
    float x[20], dx[20];
    float reducedChiSq;
  int ndf, nf;
};





class OmSourceParameters;
F90MODPROCDEF(void,omsourceparameter_mod,new_)(OmSourceParameters*,const int&, const int&);
F90MODPROCDEF(void,omsourceparameter_mod,delete_)(OmSourceParameters*);


class OmSourceParameters : public DopeVector<OmSourceParameter>
{
public:
  // f90:: allocate(OmSourceParameter(length))
  OmSourceParameters(int length)
  {
    int lbound=1;
    int ubound=length;
    F90MODPROC(omsourceparameter_mod, new_)(this, lbound, ubound);
  }

  // f90:: allocate(OmSourceParameter(lbound:ubound))
  OmSourceParameters(int lbound,int ubound)
  {
    F90MODPROC(omsourceparameter_mod,new_)(this,lbound,ubound);
    


  }
  
  // f90:: deallocate(OmSourceParameter)
  ~OmSourceParameters()
  {
    F90MODPROC(omsourceparameter_mod,delete_)(this);
  }
private:
   // disabled member functions
  OmSourceParameters();
  OmSourceParameters(const OmSourceParameters&);
  OmSourceParameters& operator=(const OmSourceParameters&);
};

/**********************************************
*
**********************************************/
struct LsqData {
    LsqData() {
        noStars = 0;
    }; 
  
    Integer1 noStars;
    bool toFit[20];  
    float i0[20];
    float x[20];
    float bl[20];
    float bu[20];
    int exitValue;
};





#endif
